==> agr-center-infrastructure-3.0.0-CLOUD-20221226.112038-2-sources.jar: com/tydic/dyc/agr/repository/po/AgrItemChngPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：agr_item_chng
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class AgrItemChngPO implements Serializable {
	private static final long serialVersionUID =  8016658757563592710L;

	/**
	 * 协议明细变更ID
	 */
	private Long agrItemChngId;
	/**
	 * 变更申请ID
	 */
	private Long chngApplyId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 明细变更类型
	 */
	private Integer itemChngType;
	/**
	 * 协议明细状态
	 */
	private Integer agrSkuStatus;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 生产厂家
	 */
	private String manufacturer;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 原价
	 */
	private Long oldPrice;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 协议明细变更ID集合
	 */
	private List<Long> agrItemChngIds;
	/**
	 * 协议明细ID集合
	 */
	private List<Long> agrItemIds;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-infrastructure-3.1.1.0-CLOUD-20230106.111323-2-sources.jar: com/tydic/dyc/agr/repository/po/AgrItemChngPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：agr_item_chng
 * 
 * @author auto_gen
 * @date 2022-11-22 10:31
 **/
@Data
public class AgrItemChngPO implements Serializable {
	private static final long serialVersionUID =  -1234174910595686161L;

	/**
	 * 协议明细变更ID
	 */
	private Long agrItemChngId;
	/**
	 * 变更申请ID
	 */
	private Long chngApplyId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 明细变更类型
	 */
	private Integer itemChngType;
	/**
	 * 协议明细状态
	 */
	private Integer agrSkuStatus;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 生产厂家
	 */
	private String manufacturer;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 原价
	 */
	private Long oldPrice;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 协议明细变更ID集合
	 */
	private List<Long> agrItemChngIds;
	/**
	 * 协议明细ID集合
	 */
	private List<Long> agrItemIds;
	/**
	 * 排序
	 */
	private String orderBy;

}
